# IBM Installation Manager (IM)

IBM Installation Manager (IM) is a single installation program that uses remote
or local software repositories to install, modify, or update certain IBM
products.

User guides and security guides to support this release are available for
online viewing
[User Guide](http://www.ibm.com/support/knowledgecenter/SSDV2W/im_family_welcome.html).


## Prerequisites

This charm makes use of resources, a feature only available in Juju 2.0. During
deploy or upgrade, you will need to specify the installable package(s)
required by this charm. Download your licensed IBM Installation Manager
packages from the [Product Page](http://www-01.ibm.com/support/docview.wss?uid=swg27025142).

### Package for Ubuntu on AMD64 (x86_64):

IBM Installation Manager 1.8.3 (`agent.installer.linux.gtk.x86_64_1.8.3000.20150606_0047.zip`)

### Package for Ubuntu on Power (ppc64le):

IBM Installation Manager 1.8.3 (`agent.installer.linux.gtk.ppc64le_1.8.3000.20150606_0047.zip`)

## Usage

To use this charm, you must agree to the Terms of Use. You can view the full license
for `IBM Installation Manager` by visiting the
[license-info](http://www-03.ibm.com/software/sla/sladb.nsf/displaylis/39AFC1C1D485C4E085257E7300548B05?OpenDocument)
page.

Search for "IBM Installation Manager" and choose the license that applies to
the version you are using.

### Deploy

Run the following commands to deploy this charm:

    juju deploy ibm-im --resource ibm_im_installer=</path/to/installer.zip>

**Note**: This charm requires acceptance of Terms of Use. When deploying from
the Charm Store, these terms will be presented to you for your consideration.
To accept the terms:

    juju agree ibm-im/1

### Upgrade

Once deployed, users can install fixpacks by upgrading the charm:

    juju attach ibm-im ibm_im_fixpack=</path/to/fixpack.zip>

### Verification

Once deployed, you can use IBM IM to install any IBM products. To verify IM is
installed, list the contents of the installation directory:

    juju run --application ibm-im 'ls /opt/IBM/InstallationManager'


## Additional information

### General

Details about IBM Installation Manager are available
[here](http://www.ibm.com/support/knowledgecenter/SSDV2W/im_family_welcome.html).

### Download

Information on procuring IBM IM product is available at the
[Product Page](http://www-01.ibm.com/support/docview.wss?uid=swg27025142).

### License

License information for IBM IM can be viewed
[here](http://www-03.ibm.com/software/sla/sladb.nsf/searchlis/?searchview&searchorder=4&searchmax=0&query=%28Installation+Manager+1.8.3%29).

### Developers

This layer is intended to be extended by other charms that would benefit from
having IBM Installation Manager (IBM IM) preinstalled. For example, a WebSphere
layered charm could include this layer so it could use IBM IM to install
WebSphere.

To use this layer, include the following in your `layer.yaml`:

```yaml
includes: ['layer:ibm-im']
```

Then in your charm, watch for the `ibm-im.installed` state, at which point you
will know the IBM IM tools are available:

```sh
IM_PATH=/opt/IBM/InstallationManager

@when 'ibm-im.installed'
install_was() {
  WAS_REPO=`config-get was_repo`
  ${IM_PATH}/tools/imutilsc saveCredential -url $WAS_REPO -userName $IBM_ID_NAME -userPassword $IBM_ID_PASS -secureStorageFile "secure.store"
  ${IM_PATH}/installc -input silent-install.xml -acceptlicense -secureStorageFile "secure.store"
  ${IM_PATH}/imcl install $IM_ARGS
}
```

## Known Limitations

This charm makes use of Juju features that are only available in version 2.0 or
greater.

## Contact Information

For issues with this charm, please contact [IBM Juju Support Team](mailto:jujusupp@us.ibm.com)
